@@ -18,7 +18,7 @@ class Options:
 module = __import__('fdroidserver.import')
 for name, obj in inspect.getmembers(module):
     if name == 'import':
-        get_metadata_from_url = obj.get_metadata_from_url
+        clone_to_tmp_dir = obj.clone_to_tmp_dir
         obj.options = Options()
         options = obj.options
         break
